<?php
/**
 * Plugin Name: Elementor Breadcrumbs Widget
 * Description: Adds a breadcrumbs widget to Elementor.
 * Version: 1.1.0
 * Author: Ulisses A. B. Dalcól
 * Author URI: https://www.vempradescomplica.com.br
 * Text Domain: elementor-breadcrumbs-widget
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

// Define constants for plugin paths
define( 'ELEMENTOR_BREADCRUMBS_WIDGET_FILE', __FILE__ );
define( 'ELEMENTOR_BREADCRUMBS_WIDGET_PLUGIN_BASE', plugin_basename( ELEMENTOR_BREADCRUMBS_WIDGET_FILE ) );
define( 'ELEMENTOR_BREADCRUMBS_WIDGET_PATH', plugin_dir_path( ELEMENTOR_BREADCRUMBS_WIDGET_FILE ) );
define( 'ELEMENTOR_BREADCRUMBS_WIDGET_URL', plugins_url( '/', ELEMENTOR_BREADCRUMBS_WIDGET_FILE ) );

class Elementor_Breadcrumbs_Widget_Plugin {
    private static $_instance = null;

    public static function instance() {
        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    public function __construct() {
        add_action( 'plugins_loaded', [ $this, 'init' ] );
    }

    public function init() {
        // Load plugin text domain
        load_plugin_textdomain( 'elementor-breadcrumbs-widget' );

        // Check if Elementor installed and activated
        if ( ! did_action( 'elementor/loaded' ) ) {
            add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
            return;
        }

        // Add Plugin actions
        add_action( 'elementor/widgets/register', [ $this, 'register_widgets' ] );
        add_action( 'wp_enqueue_scripts', [ $this, 'widget_styles' ] );

        // Add custom category
        add_action( 'elementor/elements/categories_registered', [ $this, 'add_elementor_widget_categories' ] );
    }

    public function admin_notice_missing_main_plugin() {
        if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

        $message = sprintf(
            /* translators: 1: Plugin name 2: Elementor */
            esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'elementor-breadcrumbs-widget' ),
            '<strong>' . esc_html__( 'Elementor Breadcrumbs Widget', 'elementor-breadcrumbs-widget' ) . '</strong>',
            '<strong>' . esc_html__( 'Elementor', 'elementor-breadcrumbs-widget' ) . '</strong>'
        );

        printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
    }

    public function register_widgets( $widgets_manager ) {
        require_once( ELEMENTOR_BREADCRUMBS_WIDGET_PATH . 'widgets/breadcrumbs.php' );
        $widgets_manager->register( new \ElementorBreadcrumbsWidget\Elementor_Breadcrumbs_Widget() );
    }

    public function widget_styles() {
        wp_register_style( 'elementor-breadcrumbs-style', ELEMENTOR_BREADCRUMBS_WIDGET_URL . 'assets/css/style.css' );
        wp_enqueue_style( 'elementor-breadcrumbs-style' );
    }

    public function add_elementor_widget_categories( $elements_manager ) {
        $elements_manager->add_category(
            'descomplica-comunicacao',
            [
                'title' => __( 'Descomplica Comunicação', 'elementor-breadcrumbs-widget' ),
                'icon' => 'fa fa-plug',
            ]
        );
    }
}

Elementor_Breadcrumbs_Widget_Plugin::instance();