<?php
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

class Elementor_Breadcrumbs_Widget extends \Elementor\Widget_Base {

    public function get_name() {
        return 'breadcrumbs';
    }

    public function get_title() {
        return __('Breadcrumbs', 'elementor-breadcrumbs');
    }

    public function get_icon() {
        return 'eicon-breadcrumbs';
    }

    public function get_categories() {
        return ['general'];
    }

    public function get_keywords() {
        return ['breadcrumbs', 'navigation', 'path'];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => __('Content', 'elementor-breadcrumbs'),
            ]
        );

        $this->add_control(
            'separator',
            [
                'label' => __('Separator', 'elementor-breadcrumbs'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => '/',
                'placeholder' => __('Enter separator', 'elementor-breadcrumbs'),
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_style',
            [
                'label' => __('Style', 'elementor-breadcrumbs'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'color',
            [
                'label' => __('Color', 'elementor-breadcrumbs'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .breadcrumbs' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'typography',
            [
                'label' => __('Typography', 'elementor-breadcrumbs'),
                'type' => \Elementor\Controls_Manager::TYPOGRAPHY,
                'selector' => '{{WRAPPER}} .breadcrumbs',
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();

        if (function_exists('yoast_breadcrumb')) {
            yoast_breadcrumb('<p id="breadcrumbs" class="breadcrumbs" style="color: ' . $settings['color'] . ';">', '</p>');
        } else {
            echo '<p id="breadcrumbs" class="breadcrumbs">Home ' . esc_html($settings['separator']) . ' Page</p>';
        }
    }

    protected function _content_template() {
        ?>
        <#
        var separator = settings.separator ? settings.separator : '/';
        var color = settings.color ? settings.color : '';
        var typography = settings.typography;

        #>
        <p id="breadcrumbs" class="breadcrumbs" style="color: {{ color }};">
            Home {{ separator }} Page
        </p>
        <?php
    }
}
