<?php
namespace ElementorBreadcrumbsWidget;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Elementor_Breadcrumbs_Widget extends Widget_Base {
    public function get_name() {
        return 'breadcrumbs';
    }

    public function get_title() {
        return esc_html__( 'Breadcrumbs', 'elementor-breadcrumbs-widget' );
    }

	public function get_icon() {
    return 'eicon-product-breadcrumbs';
	}
     public function get_categories() {
        return [ 'descomplica-comunicacao' ]; // Define a categoria personalizada aqui
    }
    


    public function get_keywords() {
        return [ 'breadcrumbs', 'navigation', 'path' ];
    }

    protected function register_controls() {
        $this->start_controls_section(
            'section_content',
            [
                'label' => esc_html__( 'Content', 'elementor-breadcrumbs-widget' ),
            ]
        );

        $this->add_control(
            'home_label',
            [
                'label' => esc_html__( 'Home Label', 'elementor-breadcrumbs-widget' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'Home',
                'placeholder' => esc_html__( 'Enter home label', 'elementor-breadcrumbs-widget' ),
            ]
        );

        $this->add_control(
            'separator',
            [
                'label' => esc_html__( 'Separator', 'elementor-breadcrumbs-widget' ),
                'type' => Controls_Manager::TEXT,
                'default' => '/',
                'placeholder' => esc_html__( 'Enter separator', 'elementor-breadcrumbs-widget' ),
            ]
        );

        $this->add_control(
            'home_icon',
            [
                'label' => esc_html__( 'Home Icon', 'elementor-breadcrumbs-widget' ),
                'type' => Controls_Manager::ICON,
                'default' => '',
                'placeholder' => esc_html__( 'Choose an icon', 'elementor-breadcrumbs-widget' ),
            ]
        );

        $this->end_controls_section();

         // Seção de Estilo para Texto
        $this->start_controls_section(
            'section_style_text',
            [
                'label' => esc_html__( 'Text Style', 'elementor-breadcrumbs-widget' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'color',
            [
                'label' => esc_html__( 'Color', 'elementor-breadcrumbs-widget' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .breadcrumbs' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .breadcrumbs a' => 'color: {{VALUE}};', // Ensure links are styled too
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'typography',
                'selector' => '{{WRAPPER}} .breadcrumbs, {{WRAPPER}} .breadcrumbs a',
            ]
        );

        $this->end_controls_section();

        // Seção de Estilo para Ícone
        $this->start_controls_section(
            'section_style_icon',
            [
                'label' => esc_html__( 'Icon Style', 'elementor-breadcrumbs-widget' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label' => esc_html__( 'Icon Color', 'elementor-breadcrumbs-widget' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .breadcrumbs .home-icon' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'icon_size',
            [
                'label' => esc_html__( 'Icon Size', 'elementor-breadcrumbs-widget' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .breadcrumbs .home-icon' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();

        $home_label = ! empty( $settings['home_label'] ) ? $settings['home_label'] : 'Home';
        $separator = ! empty( $settings['separator'] ) ? $settings['separator'] : '/';

        $breadcrumbs = $this->generate_breadcrumbs( $home_label, $separator, $settings['home_icon'] );

        echo $breadcrumbs;
    }

    protected function generate_breadcrumbs( $home_label, $separator, $home_icon ) {
        $breadcrumbs = [];

        // Home link with improved accessibility
        $home_link = '<a href="' . home_url() . '" aria-label="' . esc_attr__('Go to homepage', 'elementor-breadcrumbs-widget') . '">';
        if ( ! empty( $home_icon ) ) {
            $home_link .= '<i class="home-icon ' . esc_attr( $home_icon ) . '" aria-hidden="true"></i> ';
        }
        $home_link .= esc_html( $home_label ) . '</a>';
        
        $breadcrumbs[] = '<span>' . $home_link . '</span>';
        
        // WooCommerce support
        if ( class_exists( 'WooCommerce' ) && is_woocommerce() ) {
            if ( is_product_category() || is_product_tag() ) {
                $current_term = get_queried_object();
                if ( $current_term->parent ) {
                    $ancestors = get_ancestors( $current_term->term_id, $current_term->taxonomy );
                    foreach ( array_reverse( $ancestors ) as $ancestor ) {
                        $ancestor_term = get_term( $ancestor, $current_term->taxonomy );
                        $breadcrumbs[] = '<span><a href="' . get_term_link( $ancestor_term ) . '">' . esc_html( $ancestor_term->name ) . '</a></span>';
                    }
                }
                $breadcrumbs[] = '<span aria-current="page">' . esc_html( $current_term->name ) . '</span>';
            } elseif ( is_product() ) {
                $terms = get_the_terms( get_the_ID(), 'product_cat' );
                if ( $terms && ! is_wp_error( $terms ) ) {
                    $term = reset( $terms );
                    if ( $term->parent ) {
                        $ancestors = get_ancestors( $term->term_id, 'product_cat' );
                        foreach ( array_reverse( $ancestors ) as $ancestor ) {
                            $ancestor_term = get_term( $ancestor, 'product_cat' );
                            $breadcrumbs[] = '<span><a href="' . get_term_link( $ancestor_term ) . '">' . esc_html( $ancestor_term->name ) . '</a></span>';
                        }
                    }
                    $breadcrumbs[] = '<span><a href="' . get_term_link( $term ) . '">' . esc_html( $term->name ) . '</a></span>';
                }
                $breadcrumbs[] = '<span aria-current="page">' . get_the_title() . '</span>';
            }
        } else {
            if ( is_single() ) {
                $categories = get_the_category();
                if ( ! empty( $categories ) ) {
                    $category = $categories[0];
                    if ( $category->parent ) {
                        $ancestors = get_ancestors( $category->term_id, 'category' );
                        foreach ( array_reverse( $ancestors ) as $ancestor ) {
                            $ancestor_term = get_term( $ancestor, 'category' );
                            $breadcrumbs[] = '<span><a href="' . get_term_link( $ancestor_term ) . '">' . esc_html( $ancestor_term->name ) . '</a></span>';
                        }
                    }
                    $breadcrumbs[] = '<span><a href="' . get_category_link( $category->term_id ) . '">' . esc_html( $category->name ) . '</a></span>';
                }
                $breadcrumbs[] = '<span aria-current="page">' . get_the_title() . '</span>';
            } elseif ( is_page() ) {
                $post = get_post();
                if ( $post->post_parent ) {
                    $ancestors = get_post_ancestors( $post->ID );
                    foreach ( array_reverse( $ancestors ) as $ancestor ) {
                        $breadcrumbs[] = '<span><a href="' . get_permalink( $ancestor ) . '">' . get_the_title( $ancestor ) . '</a></span>';
                    }
                }
                $breadcrumbs[] = '<span aria-current="page">' . get_the_title() . '</span>';
            } elseif ( is_category() ) {
                $category = get_queried_object();
                if ( $category->parent ) {
                    $ancestors = get_ancestors( $category->term_id, 'category' );
                    foreach ( array_reverse( $ancestors ) as $ancestor ) {
                        $ancestor_term = get_term( $ancestor, 'category' );
                        $breadcrumbs[] = '<span><a href="' . get_term_link( $ancestor_term ) . '">' . esc_html( $ancestor_term->name ) . '</a></span>';
                    }
                }
                $breadcrumbs[] = '<span aria-current="page">' . single_cat_title( '', false ) . '</span>';
            }
        }

        $breadcrumbs_html = implode( ' <span class="separator" aria-hidden="true">' . esc_html( $separator ) . '</span> ', $breadcrumbs );
        return sprintf(
            '<nav aria-label="%s" class="breadcrumbs-nav">%s</nav>',
            esc_attr__('Breadcrumb', 'elementor-breadcrumbs-widget'),
            $breadcrumbs_html
        );
    }

    protected function content_template() {
        ?>
        <#
        var home_label = settings.home_label ? settings.home_label : 'Home';
        var separator = settings.separator ? settings.separator : '/';
        var home_icon = settings.home_icon ? settings.home_icon : '';

        var home_url = '<?php echo home_url(); ?>';
        var breadcrumbs = '<a href="' + home_url + '">';
        if ( home_icon ) {
            breadcrumbs += '<i class="home-icon ' + home_icon + '"></i> ';
        }
        breadcrumbs += home_label + '</a>';

		// Placeholder for the dynamic content
        breadcrumbs = '<span>' + breadcrumbs + '</span> <span>' + separator + '</span> <span>Your Content Here</span>';

        #>
        <p id="breadcrumbs" class="breadcrumbs">
            {{{ breadcrumbs }}}
        </p>
        <?php
    }
}
